@@ -1,4 +1,4 @@
-; ACL2 Version 3.2 -- A Computational Logic for Applicative Common Lisp
+; ACL2 Version 3.3 -- A Computational Logic for Applicative Common Lisp
 ; Copyright (C) 2007  University of Texas at Austin
 
 ; This version of ACL2 is a descendent of ACL2 Version 1.9, Copyright
@@ -47,6 +47,56 @@
 (if (not (fboundp 'lisp::realp))
     (setf (symbol-function 'lisp::realp) (symbol-function 'acl2-realp)))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;                         GCL VERSION QUERIES
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+#+gcl
+(defun gcl-version-> (major minor extra &optional weak)
+
+; When true, this guarantees that the current GCL version is greater than
+; major.minor.extra (or if weak is non-nil, than greater than or equal to).
+; The converse holds for versions of GCL past perhaps 2.0.
+
+  (and (boundp 'si::*gcl-major-version*)
+       (integerp si::*gcl-major-version*)
+       (if (= si::*gcl-major-version* major)
+           (and (boundp 'si::*gcl-minor-version*)
+                (integerp si::*gcl-minor-version*)
+                (if (= si::*gcl-minor-version* minor)
+                    (and (boundp 'si::*gcl-extra-version*)
+                         (integerp si::*gcl-extra-version*)
+                         (if weak
+                             (>= si::*gcl-extra-version* extra)
+                           (> si::*gcl-extra-version* extra)))
+                  (if weak
+                      (>= si::*gcl-minor-version* minor)
+                    (> si::*gcl-minor-version* minor))))
+         (if weak
+             (>= si::*gcl-major-version* major)
+           (> si::*gcl-major-version* major)))))
+
+#+gcl
+(defun gcl-version->= (major minor extra)
+  (gcl-version-> major minor extra t))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;                         COMPILED LISP FIXES
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+; Fix for GCL compiler.
+; Small example:
+; (defmacro my-mac (b)
+;   (list 'list (if (and (consp b) (stringp (car b))) (list 'quote b) b)))
+; (defun foo () (my-mac ("Guards")))
+; (compile 'foo)
+
+#+(and gcl (not ansi-cl))
+(when (and (fboundp 'compiler::wrap-literals)
+           (not (gcl-version-> 2 6 7)))
+  (setf (symbol-function 'compiler::wrap-literals)
+        (symbol-function 'identity)))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;                            PROCLAIMING
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -884,35 +934,6 @@ notation causes an error and (b) the use of ,. is not permitted."
   (declare (ignore host))
   (pathname (concatenate 'string (si::getenv "HOME") "/")))
 
-#+gcl
-(defun gcl-version-> (major minor extra &optional weak)
-
-; When true, this guarantees that the current GCL version is greater than
-; major.minor.extra (or if weak is non-nil, than greater than or equal to).
-; The converse holds for versions of GCL past perhaps 2.0.
-
-  (and (boundp 'si::*gcl-major-version*)
-       (integerp si::*gcl-major-version*)
-       (if (= si::*gcl-major-version* major)
-           (and (boundp 'si::*gcl-minor-version*)
-                (integerp si::*gcl-minor-version*)
-                (if (= si::*gcl-minor-version* minor)
-                    (and (boundp 'si::*gcl-extra-version*)
-                         (integerp si::*gcl-extra-version*)
-                         (if weak
-                             (>= si::*gcl-extra-version* extra)
-                           (> si::*gcl-extra-version* extra)))
-                  (if weak
-                      (>= si::*gcl-minor-version* minor)
-                    (> si::*gcl-minor-version* minor))))
-         (if weak
-             (>= si::*gcl-major-version* major)
-           (> si::*gcl-major-version* major)))))
-
-#+gcl
-(defun gcl-version->= (major minor extra)
-  (gcl-version-> major minor extra t))
-
 #+gcl
 (when (gcl-version->= 2 7 0)
   (setf (symbol-function 'user-homedir-pathname)
@@ -951,3 +972,5 @@ notation causes an error and (b) the use of ,. is not permitted."
   `(lisp::special-form-p ,name)
   #+(or (and DRAFT-ANSI-CL-2 (not openmcl)) cmu sbcl clisp)
   `(special-operator-p ,name))
+
+(defvar *startup-package-name* "ACL2")
