@@ -1,4 +1,4 @@
-; ACL2 Version 3.2 -- A Computational Logic for Applicative Common Lisp
+; ACL2 Version 3.3 -- A Computational Logic for Applicative Common Lisp
 ; Copyright (C) 2007  University of Texas at Austin
 
 ; This version of ACL2 is a descendent of ACL2 Version 1.9, Copyright
@@ -341,37 +341,29 @@
     (format t "SKIPPING etags: No such program is in the path.")
     (return-from make-tags 1))
   (system-call "etags"
-               #+(or cmu sbcl clisp openmcl)
-               (append '("acl2.lisp"
-                         "acl2-check.lisp"
-                         "acl2-fns.lisp"
-                         "init.lisp"
-                         "acl2-init.lisp"
-                         "akcl-acl2-trace.lisp"
-                         "allegro-acl2-trace.lisp"
-                         "openmcl-acl2-trace.lisp")
-                       (let ((result nil))
-                         (dolist
-                          (x *copy-of-acl2-files*)
-                          (setq result
-                                (cons (format nil "~a.lisp" x)
-                                      result)))
-                         (reverse result)))
-               #-(or cmu sbcl clisp openmcl)
-               (append '("acl2.lisp"
-                         "acl2-check.lisp"
-                         "acl2-fns.lisp"
-                         "init.lisp"
-                         "acl2-init.lisp"
-                         "akcl-acl2-trace.lisp"
-                         "allegro-acl2-trace.lisp")
-                       (let ((result nil))
-                         (dolist
-                          (x *copy-of-acl2-files*)
-                          (setq result
-                                (cons (format nil " ~a.lisp" x)
-                                      result)))
-                         (reverse result)))))
+               (let* ((fmt-str
+                       #+(or cmu sbcl clisp openmcl) "~a.lisp"
+                       #-(or cmu sbcl clisp openmcl) " ~a.lisp")
+                      (lst (append '("acl2.lisp"
+                                     "acl2-check.lisp"
+                                     "acl2-fns.lisp"
+                                     "init.lisp"
+                                     "acl2-init.lisp"
+                                     "akcl-acl2-trace.lisp"
+                                     "allegro-acl2-trace.lisp"
+                                     "openmcl-acl2-trace.lisp")
+                                   (let ((result nil))
+                                     (dolist
+                                       (x *copy-of-acl2-files*)
+                                       (setq result
+                                             (cons (format nil fmt-str x)
+                                                   result)))
+                                     (reverse result)))))
+
+; We want to be sure to include hons-raw.lisp even if we are not building the
+; hons version, in order to assist in maintaining both versions.
+
+                 (append lst (list "hons-raw.lisp")))))
 
 (defvar *saved-build-date*)
 (defvar *saved-mode*)
@@ -418,17 +410,9 @@
   (system-call "chmod" (list "+x" sysout-name)))
 
 (defmacro write-exec-file (stream string &rest args)
-  `(progn
-     (format
-      ,stream
-      "#!/bin/sh~%~a~%"
-      (let ((books-dir (getenv$-raw "ACL2_SYSTEM_BOOKS")))
-        (if books-dir
-            (format nil
-                    "~%export ACL2_SYSTEM_BOOKS~%ACL2_SYSTEM_BOOKS=~a~%"
-                    books-dir)
-          "")))
-     (format ,stream ,string ,@args)))
+  `(progn (format ,stream "#!/bin/sh~%~%")
+          (format ,stream "# Saved ~a~%~%" *saved-build-date*)
+          (format ,stream ,string ,@args)))
 
 #+akcl
 (defun save-acl2-in-akcl-aux (sysout-name gcl-exec-name
@@ -611,7 +595,7 @@
                                ((equal x "RELOCATABLE")
                                 (si::allocate-relocatable-pages n))
                                (t (si::allocate type n t)))))))
-            (in-package "ACL2")
+            (eval `(in-package ,*startup-package-name*))
             (lp)))
   (load "akcl-acl2-trace.lisp")
 
@@ -736,12 +720,12 @@
           (eval '(latest-release-note-string)) ; avoid possible warning
           )
   (maybe-load-acl2-init)
-  (in-package "ACL2")
+  (eval `(in-package ,*startup-package-name*))
 
 ; The following two lines follow the recommendation in Allegro CL's
 ; documentation file doc/delivery.htm.
 
-  #+allegro (tpl:setq-default *package* (find-package "ACL2"))
+  #+allegro (tpl:setq-default *package* (find-package *startup-package-name*))
   #+allegro (rplacd (assoc 'tpl::*saved-package*
                            tpl:*default-lisp-listener-bindings*)
                     'common-lisp:*package*)
@@ -1078,7 +1062,6 @@
 
                       10))
     (chmod-executable sysout-name)
-    (in-package "ACL2")
     (ext:gc)
     (ext:saveinitmem sysout-mem
                      :quiet nil
@@ -1149,7 +1132,6 @@
 #+openmcl
 (defun save-acl2-in-openmcl (sysout-name &optional mode core-name)
   (setq *saved-mode* mode)
-  (in-package "ACL2")
   #-acl2-mv-as-values (proclaim-files)
 ; We do the following load when *suppress-compile* in save-acl2, but it's
 ; harmless enough to do it again here in case *suppress-compile* is set to t.
