@@ -1,4 +1,4 @@
-; ACL2 Version 3.2 -- A Computational Logic for Applicative Common Lisp
+; ACL2 Version 3.3 -- A Computational Logic for Applicative Common Lisp
 ; Copyright (C) 2007  University of Texas at Austin
 
 ; This version of ACL2 is a descendent of ACL2 Version 1.9, Copyright
@@ -469,7 +469,7 @@
    (setq acl2::*copy-of-acl2-version*
 ;  Keep this in sync with the value of acl2-version in *initial-global-table*.
          (concatenate 'string
-                      "ACL2 Version 3.2"
+                      "ACL2 Version 3.3"
                       #+non-standard-analysis
                       "(r)"
                       #+(and mcl (not openmcl))
@@ -682,7 +682,7 @@
 
 ; The user is welcome to modify the following declaim form.
 
-(declaim (optimize #+(or cmu sbcl lucid lispworks) (compilation-speed 0)
+(declaim (optimize #+cltl2 (compilation-speed 0)
 ; The following may allow more tail recursion elimination (from "Lisp
 ; Knowledgebase" at lispworks.com); might consider for Allegro CL too.
                    #+lispworks (debug 0)
@@ -722,6 +722,29 @@
 ; Safety 1:
 ; 15343.578u 562.207s 4:27:03.67 99.2%	0+0k 0+0io 0pf+0w
 
+; Try safety 2 or 3 to find violations with Allegro CL like the car of a
+; non-nil atom.  (Note: safety 3 has failed in GCL due to a stack overflow.)
+; Here are some numbers with Allegro CL, 8 processors with make -j 8:
+
+; Safety 0:
+; 11262.699u 291.730s 38:23.72 501.5%	0+0k 0+0io 16pf+0w
+
+; Safety 2:
+; 15588.206u 285.249s 54:19.72 486.9%	0+0k 0+0io 0pf+0w
+
+; Safety 3:
+; 16450.508u 284.473s 57:46.03 482.8%	0+0k 0+0io 0pf+0w
+
+; Here are GCL numbers, again with make -j 8 (and using "fast builds").
+
+; Safety 0:
+; 10013.573u 566.983s 33:33.80 525.4%	0+0k 0+0io 0pf+0w
+
+; Safety 2:
+; [Note: books/clause-processors/SULFA/books/sat-tests/test-incremental.lisp
+; ran out of space, saving perhaps a minute]
+; 15637.669u 511.811s 52:02.78 517.1%	0+0k 0+0io 0pf+0w
+
                     0)
                    ))
 
@@ -755,11 +778,11 @@
 ; obtained for Linux, even though with-compilation-unit continues to be
 ; defined.
 
-  #+(or cltl2 cmu openmcl)
+  #+cltl2
   `(common-lisp::with-compilation-unit
     ()
     ,form)
-  #-(or cltl2 cmu)
+  #-cltl2
   form)
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -1461,12 +1484,12 @@ Newline
 ;                            CONSTANTS
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-; Allegro 6.0 (and probably later versions) warns when the following constants
-; axioms.lisp, even with boundp checks (as in ACL2 Version_2.5).  The warning
-; is a result of evaluating the defconstant twice: when loading the source file
-; and when subsequently loading the compiled file.  So starting with
-; Version_2.6 we put the constants here, since this file (acl2.lisp) is not
-; compiled and hence is only loaded once.
+; Allegro 6.0 (and probably later versions) warns when the following two (at
+; least) constants are in axioms.lisp, even with boundp checks (as in ACL2
+; Version_2.5).  The warning is a result of evaluating the defconstant twice:
+; when loading the source file and when subsequently loading the compiled file.
+; So starting with Version_2.6 we put the constants here, since this file
+; (acl2.lisp) is not compiled and hence is only loaded once.
 
 ; A slight complication is that *slashable-array* uses *slashable-chars*, which
 ; in turn is used in the definition of function some-slashable.  (There are
@@ -1517,6 +1540,37 @@ Newline
 
   32)
 
+(defconstant *boole-array*
+
+; Keep this in sync with the defconst forms just above the definition of
+; boole$.
+
+  (let ((ar (make-array 16 :element-type 'fixnum))
+        (i 0))
+    (declare (type (simple-array fixnum (*)) ar))
+    (dolist (x `((boole-1     . ,boole-1)
+                 (boole-2     . ,boole-2)
+                 (boole-and   . ,boole-and)
+                 (boole-andc1 . ,boole-andc1)
+                 (boole-andc2 . ,boole-andc2)
+                 (boole-c1    . ,boole-c1)
+                 (boole-c2    . ,boole-c2)
+                 (boole-clr   . ,boole-clr)
+                 (boole-eqv   . ,boole-eqv)
+                 (boole-ior   . ,boole-ior)
+                 (boole-nand  . ,boole-nand)
+                 (boole-nor   . ,boole-nor)
+                 (boole-orc1  . ,boole-orc1)
+                 (boole-orc2  . ,boole-orc2)
+                 (boole-set   . ,boole-set)
+                 (boole-xor   . ,boole-xor)))
+      (or (typep (cdr x) 'fixnum)
+          (error "We expected the value of ~s to be a fixnum, but it is ~s!"
+                 (car x) (cdr x)))
+      (setf (aref ar i) (cdr x))
+      (incf i))
+    ar))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;                            STATISTICS
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
