@@ -169,7 +169,7 @@
 	     (bag-leaves (cdr leaves) mfc state
 			  (cons (list (car leaves)) intp-bags)
 			  non-intp-bags))
-	    ((and (ts-subsetp leaf-type *ts-acl2-number*)
+	    ((and (ts-subsetp leaf-type *ts-rational-acl2-number*)
 		  (ts-subsetp leaf-type
 			      (ts-complement *ts-integer*)))
 	     (bag-leaves (cdr leaves) mfc state
@@ -230,7 +230,7 @@
 			  intp-bags)
 		    non-intp-bags))
 	((and (ts-subsetp (cadr (car type-alist))
-			  *ts-acl2-number*)
+			  *ts-rational-acl2-number*)
 	      (ts-subsetp (cadr (car type-alist))
 			  (ts-complement *ts-integer*)))
 	 (bag-terms (cdr type-alist) bin-op
@@ -511,6 +511,7 @@
               ("Subgoal *1/3.13" :use (two-x two-y))
               )))
 
+   #-:non-standard-analysis
    (defthm logand-thm
        (implies (and (integerp x)
                      (<= -8192 x)
@@ -522,6 +523,19 @@
                      (<= (logand x y) 8191)))
      :hints (("Goal" :use ((:instance logand-bounds
                                       (n 13))))))
+
+   #+:non-standard-analysis
+   (defthm logand-thm
+     (implies (and (integerp x)
+                   (<= -65536 x)
+                   (<= x 65535)
+                   (integerp y)
+                   (<= -65536 y)
+                   (<= y 65535))
+              (and (<= -65536 (logand x y))
+                   (<= (logand x y) 65535)))
+     :hints (("Goal" :use ((:instance logand-bounds
+                                      (n 16))))))
    
    ))
 #| 
@@ -530,7 +544,8 @@
    ()
 
    (local
-    (include-book "../../ihs/logops-lemmas"))
+    (include-book
+     "../../ihs/logops-lemmas"))
 
    (defthm logand-thm
        (implies (and (integerp x)
