@@ -68,79 +68,80 @@
 			 ((< 0 a)
 			    (< (* a x) (* a y))))))
    :hints (("Goal" :use completion-of-<)
-	   
-	   ("Subgoal 6.4.1'" :use ((:instance completion-of-<
-					     (x (complex (* a r) (* a s)))
-					     (y 0))))
+	   ("Subgoal 6.4'''" :use ((:instance completion-of-<
+                                              (x (COMPLEX (* A R) (* A S)))
+                                              (y 0))))
 	   ("Subgoal 6.3'''" :use ((:instance completion-of-<
 					     (x 0)
-					     (y (complex (* a r) (* a s))))))
-           ("Subgoal 6.2'4'" :use ((:instance completion-of-<
+					     (y (COMPLEX (* A R) (* A S))))))
+	   ("Subgoal 6.2'4'" :use ((:instance completion-of-<
+					      (x (COMPLEX 0 (* A R)))
+					      (y 0))))
+	   ("Subgoal 6.1'4'" :use ((:instance completion-of-<
+					       (x (COMPLEX 0 (* A R)))
+					       (y 0))))
+	   ("Subgoal 5.4'''" :use ((:instance completion-of-<
+                                              (x 0)
+                                              (y (COMPLEX (* A R) (* A S))))))
+	   ("Subgoal 5.3'''" :use ((:instance completion-of-<
+					     (x 0)
+					     (y (COMPLEX (* A R) (* A S))))))
+	   ("Subgoal 5.2'4'" :use ((:instance completion-of-<
+					      (x 0)
+					      (y (COMPLEX 0 (* A R))))))
+	   ("Subgoal 5.1'4'" :use ((:instance completion-of-<
 					       (x 0)
-					       (y (complex 0 (* a r))))))
-           ("Subgoal 6.1.1'" :use ((:instance completion-of-<
-                                              (x (complex 0 (* a r)))
-                                              (y 0))))
-           ("Subgoal 5.4.1'" :use ((:instance completion-of-<
+					       (y (COMPLEX 0 (* A R))))))
+	   ("Subgoal 4.4'''" :use ((:instance completion-of-<
                                               (x 0)
-                                              (y (complex (* a r) (* a s))))))
-           ("Subgoal 5.3'''" :use ((:instance completion-of-<
-                                              (x (complex (* a r) (* a s)))
+                                              (y (COMPLEX (* A R) (* A S))))))
+	   ("Subgoal 4.3'''" :use ((:instance completion-of-<
+					     (x 0)
+					     (y (COMPLEX (* A R) (* A S))))))
+	   ("Subgoal 4.2'4'" :use ((:instance completion-of-<
+					      (x 0)
+					      (y (COMPLEX 0 (* A R))))))
+	   ("Subgoal 4.1'4'" :use ((:instance completion-of-<
+					      (x 0)
+					      (y (COMPLEX 0 (* A R))))))
+	   ("Subgoal 3.4'''" :use ((:instance completion-of-<
+                                              (x (COMPLEX (* A R) (* A S)))
                                               (y 0))))
-           ("Subgoal 5.2'4'" :use ((:instance completion-of-<
-                                              (x (complex 0 (* a r)))
+	   ("Subgoal 3.3'''" :use ((:instance completion-of-<
+					     (x (COMPLEX (* A R) (* A S)))
+					     (y 0))))
+	   ("Subgoal 3.2'4'" :use ((:instance completion-of-<
+					      (x (COMPLEX 0 (* A R)))
 					      (y 0))))
-           ("Subgoal 5.1.1'" :use ((:instance completion-of-<
-                                              (x 0)
-                                              (y (complex 0 (* a r))))))
-           ("Subgoal 4.4.1'" :use ((:instance completion-of-<
-                                              (x 0)
-                                              (y (complex (* a r) (* a s))))))
-           ("Subgoal 4.3'''" :use ((:instance completion-of-<
-                                              (x (complex (* a r) (* a s)))
-                                              (y 0))))
-           ("Subgoal 4.2'4'" :use ((:instance completion-of-<
-                                              (x (complex 0 (* a r)))
-					      (y 0))))
-           ("Subgoal 4.1.1'" :use ((:instance completion-of-<
-                                              (x 0)
-                                              (y (complex 0 (* a r))))))
-           ("Subgoal 3.4.1'" :use ((:instance completion-of-<
-                                              (x (complex (* a r) (* a s)))
-                                              (y 0))))
-           ("Subgoal 3.3'''" :use ((:instance completion-of-<
-                                              (x 0)
-                                              (y (complex (* a r) (* a s))))))
-           ("Subgoal 3.2'4'" :use ((:instance completion-of-<
-                                              (x 0)
-                                              (y (complex 0 (* a r))))))
-           ("Subgoal 3.1.1'" :use ((:instance completion-of-<
-                                              (x 0)
-                                              (y (complex 0 (* a r))))))
+	   ("Subgoal 3.1'4'" :use ((:instance completion-of-<
+					       (x (COMPLEX 0 (* A R)))
+					       (y 0))))
+           
            ("Subgoal 2.4'5'" :use ((:instance completion-of-<
-                                              (x (complex (* a i) (* a j)))
-                                              (y (complex (* a r) (* a s))))))
+					      (x (COMPLEX (* A R) (* A S)))
+                                              (y (COMPLEX (* A I) (* A J))))))
            ("Subgoal 2.3'5'" :use ((:instance completion-of-<
-                                              (x (complex (* a i) (* a j)))
-                                              (y (complex (* a r) (* a s))))))
+					      (x (COMPLEX (* A R) (* A S)))
+                                              (y (COMPLEX (* A I) (* A J))))))
            ("Subgoal 2.2'6'" :use ((:instance completion-of-<
-                                              (x (complex (* a r) (* a s)))
-                                              (y (complex (* a r) (* a i))))))
+					      (x (COMPLEX (* A R) (* A S)))
+                                              (y (COMPLEX (* A R) (* A I))))))
            ("Subgoal 2.1'6'" :use ((:instance completion-of-<
-                                              (x (complex (* a r) (* a s)))
-                                              (y (complex (* a r) (* a i))))))
+					      (x (COMPLEX (* A R) (* A S)))
+                                              (y (COMPLEX (* A R) (* A I))))))
+           
            ("Subgoal 1.4'5'" :use ((:instance completion-of-<
-                                              (x (complex (* a i) (* a j)))
-                                              (y (complex (* a r) (* a s))))))
+					      (x (COMPLEX (* A I) (* A J)))
+                                              (y (COMPLEX (* A R) (* A S))))))
            ("Subgoal 1.3'5'" :use ((:instance completion-of-<
-                                              (x (complex (* a r) (* a s)))
-                                              (y (complex (* a i) (* a j))))))
+					      (x (COMPLEX (* A I) (* A J)))
+                                              (y (COMPLEX (* A R) (* A S))))))
            ("Subgoal 1.2'6'" :use ((:instance completion-of-<
-                                              (x (complex (* a r) (* a s)))
-                                              (y (complex (* a r) (* a i))))))
+					      (x (COMPLEX (* A R) (* A I)))
+                                              (y (COMPLEX (* A R) (* A S))))))
            ("Subgoal 1.1'6'" :use ((:instance completion-of-<
-                                              (x (complex (* a r) (* a i)))
-                                              (y (complex (* a r) (* a s)))))))))
+					      (x (COMPLEX (* A R) (* A I)))
+                                              (y (COMPLEX (* A R) (* A S)))))))))
 
 (local
  (in-theory (disable hack0 hack1 step-one)))
