@@ -273,7 +273,7 @@
 ;;
 ;;-----------------------------------------------------------------
 
-(defun floor* (x y)
+(defun floor-induct-fn (x y)
   (declare (xargs :measure (abs (floor x y))))
     (cond ((not (rationalp x))
 	   t)
@@ -283,20 +283,20 @@
 	   t)
 	  ((< y 0)
 	   (cond ((< 0 x)
-		  (1- (floor* (+ x y) y)))
+		  (1- (floor-induct-fn (+ x y) y)))
 		 ((< y x)
 		  t)
 		 (t
-		  (1+ (floor* (- x y) y)))))
+		  (1+ (floor-induct-fn (- x y) y)))))
 	  (t  ;; (< 0 y)
 	   (cond ((< x 0)
-		  (1- (floor* (+ x y) y)))
+		  (1- (floor-induct-fn (+ x y) y)))
 		 ((< x y)
 		  t)
 		 (t
-		  (1+ (floor* (- x y) y)))))))
+		  (1+ (floor-induct-fn (- x y) y)))))))
 
-(defun mod* (x y)
+(defun mod-induct-fn (x y)
   (declare (xargs :measure (abs (floor x y))))
     (cond ((not (rationalp x))
 	   t)
@@ -306,28 +306,28 @@
 	   t)
 	  ((< y 0)
 	   (cond ((< 0 x)
-		  (mod* (+ x y) y))
+		  (mod-induct-fn (+ x y) y))
 		 ((< y x)
 		  t)
 		 (t
-		  (mod* (- x y) y))))
+		  (mod-induct-fn (- x y) y))))
 	  (t  ;; (< 0 y)
 	   (cond ((< x 0)
-		  (mod* (+ x y) y))
+		  (mod-induct-fn (+ x y) y))
 		 ((< x y)
 		  t)
 		 (t
-		  (mod* (- x y) y))))))
+		  (mod-induct-fn (- x y) y))))))
 
 (defthm floor-ind
   t
   :rule-classes ((:induction :pattern (floor x y)
-			     :scheme (floor* x y))))
+			     :scheme (floor-induct-fn x y))))
 
 (defthm mod-ind
   t
   :rule-classes ((:induction :pattern (mod x y)
-			     :scheme (mod* x y))))
+			     :scheme (mod-induct-fn x y))))
 
 (in-theory (disable floor-ind mod-ind))
 
