@@ -700,7 +700,31 @@
 
    (value-triple '(value-triple nil))))
 
-; Test generalizing alist.
+; Test generalizing alist.  (This example is referenced in :doc
+; clause-processor.)
+
+; In this example we illustrate generalization.  A more interesting example
+; would take a "user hint" argument that is the term to generalize, perhaps
+; together with the variable to generalize it to.  The variable could actually
+; be computed, though, for example as follows:
+
+#||
+   ACL2 !>(genvar 'genvar ; this time, a symbol in the "ACL2" package
+                   "X" ; prefix
+                   0   ; root
+                   ;; avoid-lst from clause
+                   (all-vars1-lst '((not (foo x0)) (bar x1) (g x3))
+                                  nil ; accumulator
+                                  )
+                   )
+   X2
+   ACL2 !>
+||#
+
+; Anyhow, here we do something much simpler: when a clause has a single literal
+; that is a call of function f4, replace that literal by (f4 y).  This isn't
+; sound in general, of course; but here, it's OK because f4 is constrained to
+; return a non-nil value.
 
 (encapsulate
  ((f4 (x) t))
@@ -712,35 +736,57 @@
   ((f4 x)))
 
 (defun gen-cl (cl)
+; Replace clause cl by a list of clauses whose validity implies the validity of
+; cl.
   (case-match cl
     ((('f4 &))
-     '(((f4 a))))
+     '(((f4 y))))
     (& (list cl))))
 
 (defun gen-cl-alist (cl a)
+; The value of clause cl, with respect to binding alist a, corresponds to the
+; value of clause list (gen-cl cl) with respect to binding list (gen-cl-alist
+; cl a).  Since gen-cl maps the clause containing unique literal (f4 term) to a
+; singleton clause containing (f4 y), this new binding alist should map y to
+; the value of term in the given alist, a.
   (case-match cl
-    ((('f4 x))
-     (list (cons 'a (ev3 x a))))
+    ((('f4 term))
+     (list (cons 'y (ev3 term a))))
     (& a)))
 
+; Now unlike the typical :clause-processor rule, here the ev3 hypothesis uses
+; the generalizing binding alist, (gen-cl-alist cl a), in place of the given
+; binding alist, a.
 (defthm correctness-of-gen-cl
   (implies (and (pseudo-term-listp cl)
                 (alistp a)
-                (ev3 (conjoin-clauses
-                      (gen-cl cl))
+                (ev3 (conjoin-clauses (gen-cl cl))
                      (gen-cl-alist cl a)))
            (ev3 (disjoin cl) a))
   :hints (("Goal" :in-theory (enable f4-prop)))
   :rule-classes :clause-processor)
 
+; Since f4-prop is disabled, this next rule will be the only way to rewrite a
+; call of f4 to t.  So the next theorem, f4-test, tests that the expected
+; generalization really is taking place to produce the clause containing single
+; literal (f4 y).
+
+
 (defthm f4-prop-restricted
-  (implies (syntaxp (eq x 'a))
+  (implies (syntaxp (eq x 'y))
            (f4 x))
   :hints (("Goal" :in-theory (enable f4-prop))))
 
+(must-fail ; Hint needs to be on "Goal'", not "Goal".
+ (defthm f4-test
+   (car (cons (f4 (+ u v)) w))
+   :hints (("Goal" :clause-processor (:function gen-cl)))))
+
 (defthm f4-test
   (car (cons (f4 (+ u v)) w))
-  :hints (("Goal" :clause-processor (:function gen-cl))))
+  :hints (("Goal'" :clause-processor (:function gen-cl))))
+
+; End of "Test generalizing alist" example.
 
 ; Let's try user-defined stobjs and then look at the error message about
 ; non-executability.
