@@ -247,7 +247,8 @@
 	(in-list a (cdr x)))))
 
 (defun mergesort-exec (x)
-  (declare (xargs :guard (true-listp x)))
+  (declare (xargs :guard (true-listp x)
+                  :measure (:? x)))
   (cond ((endp x) nil)
 	((endp (cdr x)) (insert (car x) nil))
         (t (mv-let (part1 part2)
