@@ -3,7 +3,7 @@
 ;(b1) - this fails because "bar" contains a defaxiom and when we do
 ;      the chk-embedded-event-form on the forms in "bar" we know
 ;      in-local-flg.
-(local (include-book "bar"))
+(local (include-book "bar" :ttags (:writes-okp)))
 
 (defthm bad
   nil
