@@ -3,7 +3,7 @@
 (defmacro my-local (x) `(local ,x))
 
 ;(b2) - as with (b1) but with macro for local
-(my-local (include-book "bar"))
+(my-local (include-book "bar" :ttags (:writes-okp)))
 
 (defthm bad
   nil
