@@ -1,7 +1,7 @@
 (in-package "ACL2")
 
 ;(b3) - as with (b1) but with two levels of include-book
-(local (include-book "baruser"))
+(local (include-book "baruser" :ttags (:writes-okp)))
 
 (defthm bad
   nil
