@@ -3,7 +3,7 @@
 (defmacro my-local (x) `(local ,x))
 
 ;(c2)
-(encapsulate () (my-local (include-book "bar"))
+(encapsulate () (my-local (include-book "bar" :ttags (:writes-okp)))
 
 (defthm bad
   nil
