@@ -3,7 +3,7 @@
 (defmacro my-local (x) `(local ,x))
 
 ;(f) - this fails because of non-local include-book in an encapsulate
-(encapsulate () (include-book "bar")
+(encapsulate () (include-book "bar" :ttags (:writes-okp))
 
 (defthm bad
   nil
