@@ -55,6 +55,10 @@
 ; List Processing
 
 (defun firstn (n l)
+  "The sublist of L consisting of its first N elements."
+  (declare (xargs :guard (and (true-listp l)
+                              (integerp n)
+                              (<= 0 n))))
   (cond ((endp l) nil)
         ((zp n) nil)
         (t (cons (car l)
