@@ -265,22 +265,22 @@
 ;helper for progn+touchable and progn=touchable
 (defmacro progn-touchable-keyword (addp form-lst &key vars fns)
   (declare (xargs :guard form-lst))
-  `(progn! (state-global-let*
-            ((temp-touchable-vars
-              (add-temp-touchable-aliases ',vars
-                                          ,(if addp
-                                             '(@ temp-touchable-vars)
-                                             'nil)
-                                          nil)
-              set-temp-touchable-vars)
-             (temp-touchable-fns
-              (add-temp-touchable-aliases ',fns
-                                          ,(if addp
-                                             '(@ temp-touchable-fns)
-                                             'nil)
-                                          't)
-              set-temp-touchable-fns))
-            (progn . ,form-lst))))
+  `(progn! :state-global-bindings
+           ((temp-touchable-vars
+             (add-temp-touchable-aliases ',vars
+                                         ,(if addp
+                                              '(@ temp-touchable-vars)
+                                            'nil)
+                                         nil)
+             set-temp-touchable-vars)
+            (temp-touchable-fns
+             (add-temp-touchable-aliases ',fns
+                                         ,(if addp
+                                              '(@ temp-touchable-fns)
+                                            'nil)
+                                         't)
+             set-temp-touchable-fns))
+           (progn . ,form-lst)))
 
 ;for export
 (defmacro progn+touchable (&rest args)
@@ -389,13 +389,13 @@
 
 (defmacro progn+redef-action (spec &rest form-lst)
   (declare (xargs :guard form-lst))
-  `(progn! (state-global-let*
-            ((ld-redefinition-action
-              ,(if (eq spec :unspecified)
-                 '(@ ld-redefinition-action)
-                 `(expand-redef-action-aliases ',spec))
-              put-ld-redefinition-action))
-            (progn . ,form-lst))))
+  `(progn! :state-global-bindings
+           ((ld-redefinition-action
+             ,(if (eq spec :unspecified)
+                  '(@ ld-redefinition-action)
+                `(expand-redef-action-aliases ',spec))
+             put-ld-redefinition-action))
+           (progn . ,form-lst)))
 
 ; for export
 (defmacro progn+redef (&rest args)
