@@ -42,86 +42,86 @@
 
   (prog2$
    (initialize-brr-stack state)
-   (let ((ens (ens state))
-         (saved-pspv (make-pspv wrld
-                                :displayed-goal term ; from, e.g., thm-fn
-                                :user-supplied-term term ;from, e.g., prove
-                                :orig-hints thints))) ;from, e.g., prove
-     (let* ((new-lit (fcons-term* 'equal (fcons-term* 'hide 'xxx) term))
-            (current-clause (add-literal new-lit
-                                         (dumb-negate-lit-lst hyps) t)))
-       (er-let* ;from waterfall1
-        ((pair
-          (find-applicable-hint-settings
-           *initial-clause-id*
-           current-clause
-           nil saved-pspv ctx
-           thints thints wrld nil state)))
-        (let ((hint-settings (car pair))
-              (thints (cdr pair)))
-          (pprogn
-           (cond ((null hint-settings)
-                  state)
-                 (t (thanks-for-the-hint nil state))) ;BB
-           (let ((pspv (load-hint-settings-into-pspv
-                        t hint-settings saved-pspv wrld)))
-             (cond
-              ((intersectp-eq
-                '(:do-not-induct :do-not :induct :use :cases :by)
-                (strip-cars hint-settings))
-               (er soft ctx
-                   "It makes no sense for SIMPLIFY-TERM to be given hints for ~
-                    \"Goal\" that include any of :do-not-induct, :do-not, ~
-                    :induct, :use, :cases, or :by.  The hint ~p0 is therefore ~
-                    illegal."
-                   (cons "Goal" hint-settings)))
-              (t (pprogn
-                  (initialize-proof-tree ;from waterfall
-                   *initial-clause-id*
-                   (list (list (implicate (conjoin hyps) term)))
-                   ctx
-                   state)
-                  (let* ;from simplify-clause1
-                      ((rcnst
-                        (change rewrite-constant
-                                (access prove-spec-var pspv :rewrite-constant)
-                                :force-info
-                                (if (ffnnamep-lst 'if current-clause)
-                                    'weak
-                                  t)))
-                       (pts nil))
-                    (mv-let
-                     (contradictionp type-alist fc-pair-lst)
-                     (forward-chain current-clause
-                                    pts
-                                    (access rewrite-constant
-                                            rcnst :force-info)
-                                    nil wrld ens
-                                    (access rewrite-constant
-                                            rcnst :oncep-override)
-                                    state)
-                     (declare (ignore fc-pair-lst))
-                     (cond
-                      (contradictionp
-                       (er soft ctx
-                           "Contradiction found in hypotheses using ~
-                            type-set reasoning!"))
-                      (t
-                       (mv-let ;from simplify-clause1
-                        (contradictionp simplify-clause-pot-lst)
-                        (setup-simplify-clause-pot-lst current-clause
-                                                       (pts-to-ttree-lst 
-                                                        pts)
-                                                       nil  ;; RBK: fc-pair-lst
-                                                       type-alist
-                                                       rcnst
-                                                       wrld state)
-                        (cond
-                         (contradictionp
-                          (er soft ctx
-                              "Contradiction found in hypotheses using linear ~
-                               reasoning!"))
-                         (t
+   (let* ((ens (ens state))
+          (saved-pspv (make-pspv ens wrld
+                                 :displayed-goal term ; from, e.g., thm-fn
+                                 :user-supplied-term term ;from, e.g., prove
+                                 :orig-hints thints)) ;from, e.g., prove
+          (new-lit (fcons-term* 'equal (fcons-term* 'hide 'xxx) term))
+          (current-clause (add-literal new-lit
+                                       (dumb-negate-lit-lst hyps) t)))
+     (er-let* ;from waterfall1
+      ((pair
+        (find-applicable-hint-settings
+         *initial-clause-id*
+         current-clause
+         nil saved-pspv ctx
+         thints thints wrld nil state)))
+      (let ((hint-settings (car pair))
+            (thints (cdr pair)))
+        (pprogn
+         (cond ((null hint-settings)
+                state)
+               (t (thanks-for-the-hint nil state))) ;BB
+         (er-let* ((pspv (load-hint-settings-into-pspv
+                          t hint-settings saved-pspv wrld ctx state)))
+           (cond
+            ((intersectp-eq
+              '(:do-not-induct :do-not :induct :use :cases :by)
+              (strip-cars hint-settings))
+             (er soft ctx
+                 "It makes no sense for SIMPLIFY-TERM to be given hints for ~
+                  \"Goal\" that include any of :do-not-induct, :do-not, ~
+                  :induct, :use, :cases, or :by.  The hint ~p0 is therefore ~
+                  illegal."
+                 (cons "Goal" hint-settings)))
+            (t (pprogn
+                (initialize-proof-tree ;from waterfall
+                 *initial-clause-id*
+                 (list (list (implicate (conjoin hyps) term)))
+                 ctx
+                 state)
+                (let* ;from simplify-clause1
+                    ((rcnst
+                      (change rewrite-constant
+                              (access prove-spec-var pspv :rewrite-constant)
+                              :force-info
+                              (if (ffnnamep-lst 'if current-clause)
+                                  'weak
+                                t)))
+                     (pts nil))
+                  (mv-let
+                   (contradictionp type-alist fc-pair-lst)
+                   (forward-chain current-clause
+                                  pts
+                                  (access rewrite-constant
+                                          rcnst :force-info)
+                                  nil wrld ens
+                                  (access rewrite-constant
+                                          rcnst :oncep-override)
+                                  state)
+                   (declare (ignore fc-pair-lst))
+                   (cond
+                    (contradictionp
+                     (er soft ctx
+                         "Contradiction found in hypotheses using type-set ~
+                          reasoning!"))
+                    (t
+                     (mv-let ;from simplify-clause1
+                      (contradictionp simplify-clause-pot-lst)
+                      (setup-simplify-clause-pot-lst current-clause
+                                                     (pts-to-ttree-lst 
+                                                      pts)
+                                                     nil ;; RBK: fc-pair-lst
+                                                     type-alist
+                                                     rcnst
+                                                     wrld state)
+                      (cond
+                       (contradictionp
+                        (er soft ctx
+                            "Contradiction found in hypotheses using linear ~
+                             reasoning!"))
+                       (t
 
 ; We skip the call of process-equational-polys in simplify-clause1; I think
 ; that we can assume that by the time this is called, that call wouldn't have
@@ -130,76 +130,76 @@
 
 ; Now we continue as in rewrite-clause.
 
-                          (let ((local-rcnst
-                                 (change rewrite-constant rcnst
-                                         :current-literal
-                                         (make current-literal
-                                               :not-flg nil
-                                               :atm term)))
-                                (gstack (initial-gstack 'simplify-clause
-                                                        nil
-                                                        current-clause)))
-                            (mv-let
-                             (rewritten-term ttree)
-                             (rewrite-entry
-                              (rewrite term nil 1)
-                              :rdepth (rewrite-stack-limit wrld)
-                              :obj '?
-                              :fnstack nil
-                              :ancestors nil
-                              :pre-dwp nil
-                              :backchain-limit 500
-                              :geneqv
-                              (cadr (car (last (getprop
-                                                equiv
-                                                'congruences
-                                                nil
-                                                'current-acl2-world
-                                                wrld)))))
-                             (mv-let
-                              (bad-ass ttree)
-                              (resume-suspended-assumption-rewriting
-                               ttree
-                               nil
-                               gstack
-                               simplify-clause-pot-lst
-                               local-rcnst
-                               wrld
-                               state)
-                              (cond
-                               (bad-ass
-                                (er soft ctx
-                                    "Generated false assumption, ~p0!  So, ~
+                        (let ((local-rcnst
+                               (change rewrite-constant rcnst
+                                       :current-literal
+                                       (make current-literal
+                                             :not-flg nil
+                                             :atm term)))
+                              (gstack (initial-gstack 'simplify-clause
+                                                      nil
+                                                      current-clause)))
+                          (mv-let
+                           (rewritten-term ttree)
+                           (rewrite-entry
+                            (rewrite term nil 1)
+                            :rdepth (rewrite-stack-limit wrld)
+                            :obj '?
+                            :fnstack nil
+                            :ancestors nil
+                            :pre-dwp nil
+                            :backchain-limit 500
+                            :geneqv
+                            (cadr (car (last (getprop
+                                              equiv
+                                              'congruences
+                                              nil
+                                              'current-acl2-world
+                                              wrld)))))
+                           (mv-let
+                            (bad-ass ttree)
+                            (resume-suspended-assumption-rewriting
+                             ttree
+                             nil
+                             gstack
+                             simplify-clause-pot-lst
+                             local-rcnst
+                             wrld
+                             state)
+                            (cond
+                             (bad-ass
+                              (er soft ctx
+                                  "Generated false assumption, ~p0!  So, ~
                                      rewriting is aborted, just as it would ~
                                      be in the course of a regular ACL2 proof."
-                                    bad-ass))
-                               (prove-assumptions
-                                (mv-let
-                                 (pairs pspv state)
-                                 (process-assumptions
-                                  0
-                                  (change prove-spec-var saved-pspv
-                                          :tag-tree
-                                          (set-cl-ids-of-assumptions
-                                           ttree *initial-clause-id*))
-                                  wrld state)
-                                 (er-let*
-                                  ((ttree
-                                    (accumulate-ttree-into-state
-                                     (access prove-spec-var pspv :tag-tree)
-                                     state))
-                                   (thints (value thints)))
-                                  (er-let*
-                                   ((new-ttree
-                                     (prove-loop1 1 nil pairs pspv
-                                                  thints wrld ctx state)))
-                                   (value (cons rewritten-term
-                                                (cons-tag-trees
-                                                 ttree
-                                                 new-ttree)))))))
-                               (t
-                                (value (cons rewritten-term
-                                             ttree)))))))))))))))))))))))))
+                                  bad-ass))
+                             (prove-assumptions
+                              (mv-let
+                               (pairs pspv state)
+                               (process-assumptions
+                                0
+                                (change prove-spec-var saved-pspv
+                                        :tag-tree
+                                        (set-cl-ids-of-assumptions
+                                         ttree *initial-clause-id*))
+                                wrld state)
+                               (er-let*
+                                ((ttree
+                                  (accumulate-ttree-into-state
+                                   (access prove-spec-var pspv :tag-tree)
+                                   state))
+                                 (thints (value thints)))
+                                (er-let*
+                                 ((new-ttree
+                                   (prove-loop1 1 nil pairs pspv
+                                                thints ens wrld ctx state)))
+                                 (value (cons rewritten-term
+                                              (cons-tag-trees
+                                               ttree
+                                               new-ttree)))))))
+                             (t
+                              (value (cons rewritten-term
+                                           ttree))))))))))))))))))))))))
 
 (defun simplify-term* (remaining-iters ttree term hyps equiv thints
                                        prove-assumptions ctx wrld state)
@@ -293,6 +293,12 @@
 ;;; Definition and Lemma Generation (except lemmas for mutual-recursion)
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
+(defun sublis-fn! (alist term)
+  (mv-let (erp new-term)
+          (sublis-fn alist term nil)
+          (assert$ (null erp)
+                   new-term)))
+
 (defun %f-is-f-lemmas-rev (%f f formals-decls orig-body
                               untranslated-new-body
                               translated-new-body
@@ -381,8 +387,8 @@
                  (local
                   (defun ,%%f ,formals
                     ,@(cdr formals-decls) ; to include original measure etc.
-                    ,(untranslate (sublis-fn (list (cons %f %%f))
-                                             translated-new-body)
+                    ,(untranslate (sublis-fn! (list (cons %f %%f))
+                                              translated-new-body)
                                   nil wrld)))))
          (equal-bodies nil)
          (t `((local
