@@ -280,9 +280,10 @@
   Note that the printing of ~c[(f$ x y yourstobj)] will not be altered.
 
   ~l[untranslate-patterns-table] for more examples and details.~/"  
-  `(if (fquotep ',target)
-       (add-untranslate-pattern-constant ,(cadr target) ,replacement)
-     (add-untranslate-pattern-function ,target ,replacement)))
+  (if (and (consp target)
+           (eq (car target) 'quote))
+      `(add-untranslate-pattern-constant ,(cadr target) ,replacement)
+    `(add-untranslate-pattern-function ,target ,replacement)))
 
 
 (defmacro optimize-untranslate-patterns ()
