@@ -2026,9 +2026,7 @@
 
 ; Avoid looping:
 (theory-invariant
- (not (and (member-equal '(:rewrite natp-integerp-bridge)
-                         theory)
-           (member-equal '(:definition natp)
-                         theory)))
+ (not (and (active-runep '(:rewrite natp-integerp-bridge))
+           (active-runep '(:definition natp))))
  :key :natp-integerp-bridge-invariant)
 
