@@ -26,11 +26,17 @@
   (floor x 1))
 
 (defund bits (x i j)
-  (declare (xargs :guard (rationalp x)))
-  (if (or (not (integerp i))
-          (not (integerp j)))
-      0
-    (fl (/ (mod x (expt 2 (1+ i))) (expt 2 j)))))
+  (declare (xargs :guard (and (natp x)
+                              (natp i)
+                              (natp j))
+                  :verify-guards nil))
+  (mbe :logic (if (or (not (integerp i))
+                      (not (integerp j)))
+                  0
+                (fl (/ (mod x (expt 2 (1+ i))) (expt 2 j))))
+       :exec  (if (< i j)
+                  0
+                (logand (ash x (- j)) (1- (ash 1 (1+ (- i j))))))))
 
 (defun expo-measure (x)
 ;  (declare (xargs :guard (and (real/rationalp x) (not (equal x 0)))))
@@ -53,8 +59,11 @@
 ;;
 
 (defund bitn (x n)
-  (declare (xargs :guard (rationalp x)))
-  (bits x n n))
+  (declare (xargs :guard (and (natp x)
+                              (natp n))
+                  :verify-guards nil))
+  (mbe :logic (bits x n n)
+       :exec  (if (evenp (ash x (- n))) 0 1)))
 
 (defthm bitn-with-n-not-an-integer
   (implies (not (integerp n))
@@ -405,7 +414,7 @@
   (implies (and (syntaxp (not (quotep x)))
                 (acl2-numberp n))
            (equal (BITN (* 2 x) n)
-                  (bitn x (+ -1 n)))))
+                  (bitn x (1- n)))))
 
 (defthmd bitn-plus-mult
   (implies (and (< n m)
@@ -415,6 +424,12 @@
            (equal (bitn (+ x (* k (expt 2 m))) n)
                   (bitn x n))))
 
+(defthmd bitn-plus-mult-rewrite
+    (implies (and (syntaxp (quotep c))
+		  (equal (mod c (expt 2 (1+ n))) 0))
+	     (equal (bitn (+ c x) n)
+		    (bitn x n))))
+
 ;we almost always want to leave this disabled!
 (defthmd bitn-plus-bits
   (implies (and (<= m n)
@@ -640,4 +655,4 @@
                 (case-split (<= 0 i))
                 )
   (equal (bits (bitn x n) i 0)
-         (bitn x n))))
\ No newline at end of file
+         (bitn x n))))
