@@ -9,6 +9,7 @@
 (local (include-book "trunc"))
 (local (include-book "away"))
 (local (include-book "near"))
+(local (include-book "near+"))
 (local (include-book "sticky"))
 (local (include-book "../arithmetic/top"))
 
@@ -93,6 +94,12 @@
 	    (trunc x n)
 	  (away x n))))))
 
+(defund near+ (x n)
+  (if (< (re (* (expt 2 (1- n)) (sig x)))
+	 1/2)
+      (trunc x n)
+    (away x n)))
+
 (defund sticky (x n)
   (cond ((exactp x (1- n)) x)
 	(t (+ (trunc x (1- n))
@@ -111,6 +118,7 @@
 (defund rnd (x mode n)
   (case mode
     (away (away x n)) ;added by eric in august, 2001
+    (near+ (near+ x n))
     (trunc (trunc x n))
     (inf (inf x n))
     (minf (minf x n))
@@ -121,7 +129,7 @@
   (member mode '(trunc inf minf near)))
 
 (defund rounding-mode-p (mode)
-  (or (IEEE-mode-p mode) (equal mode 'away)))
+  (or (IEEE-mode-p mode) (equal mode 'away) (equal mode 'near+)))
 
 (defund flip (m)
   (case m
@@ -952,7 +960,7 @@
            (or (= (drnd x mode n k) 0)
                (= (abs (drnd x mode n k)) (smallest-positive-denormal n k))))
   :hints (("Goal" :in-theory (set-difference-theories
-                              (enable rnd inf minf near ieee-mode-p rounding-mode-p sgn drnd-rewrite
+                              (enable rnd inf minf near near+ ieee-mode-p rounding-mode-p sgn drnd-rewrite
                                       )
                               '(smallest-positive-denormal
                                 smallest-positive-normal 
@@ -1052,7 +1060,7 @@
                 (integerp k)
                 (> k 0))
            (= (expo (largest-positive-denormal n k))
-              (+ -1 (expo (smallest-positive-normal k)))))  
+              (1- (expo (smallest-positive-normal k)))))  
   :hints (("Goal" :in-theory (enable largest-positive-denormal
                                      SMALLEST-POSITIVE-NORMAL
                                      SMALLEST-POSITIVE-deNORMAL))))
@@ -1079,7 +1087,7 @@
                 (integerp k)
                 (> k 0))
            (exactp (largest-positive-denormal n k)
-                   (+ -1 n)))
+                   (1- n)))
   :hints (("Goal" :in-theory (e/d (largest-positive-denormal
                                    SMALLEST-POSITIVE-NORMAL
                                    SMALLEST-POSITIVE-deNORMAL) ( exactp-diff-of-powers-of-2))
@@ -1100,8 +1108,8 @@
            :use ( (:instance expo-lpd)
                   (:instance exactness-of-lpd)
                   (:instance expt-strong-monotone 
-                             (n (+ 3 (* -1 n) (* -1 (EXPT 2 (+ -1 k)))))
-                             (m (+ 2 (* -1 (EXPT 2 (+ -1 k))))))))))
+                             (n (+ 3 (* -1 n) (* -1 (EXPT 2 (1- k)))))
+                             (m (+ 2 (* -1 (EXPT 2 (1- k))))))))))
 
 ;BOZO move these
 ;nice rules to have in lib?
@@ -1227,7 +1235,7 @@
 
 (local 
  (defthm hack3
-   (implies (and (equal (expo x) (- 1 (expt 2 (+ -1 k))))
+   (implies (and (equal (expo x) (- 1 (expt 2 (1- k))))
                  (rationalp x)
                  (integerp n)
                  (< 1 n)
@@ -1236,8 +1244,8 @@
             (> (+ (expt 2 (+ 1 (expo x)))
                   (expt 2
                         (+ 3 (* -1 n)
-                           (* -1 (expt 2 (+ -1 k))))))
-               (expt 2 (+ 2 (* -1 (expt 2 (+ -1 k)))))))
+                           (* -1 (expt 2 (1- k))))))
+               (expt 2 (+ 2 (* -1 (expt 2 (1- k)))))))
    :rule-classes nil 
    :hints (("Goal" :in-theory (disable   REARRANGE-NEGATIVE-COEFS-EQUAL)))))
 
@@ -1275,7 +1283,7 @@
                                   (* -1 (bias k)))))
                  (:instance rnd-exactp-c (a (largest-positive-denormal n k))
                             (mode m)
-                            (n (+ -1 n)))
+                            (n (1- n)))
                  hack3 ;hack3-bias
 
                  ))
@@ -1326,7 +1334,7 @@
                 (rounding-mode-p m))
            (not (equal (drnd x m n k) 0)))
   :hints (("goal" :in-theory (set-difference-theories
-                              (enable rnd inf minf near
+                              (enable rnd inf minf near near+
                                       drnd-rewrite
                                       rounding-mode-p ieee-mode-p
                                       smallest-positive-denormal
@@ -1397,14 +1405,14 @@
            (<= (* 2
                    (expt 2
                          (+ 3 (* -1 n)
-                            (* -1 (expt 2 (+ -1 k))))))
-               (expt 2 (+ 2 (* -1 (expt 2 (+ -1 k)))))))
+                            (* -1 (expt 2 (1- k))))))
+               (expt 2 (+ 2 (* -1 (expt 2 (1- k)))))))
   :hints (("goal" :in-theory (disable expo>=-2)
-           :use ((:instance a15 (i 2) (j1 1) (j2 (+ 3 (* -1 n) (* -1 (expt 2 (+ -1 k))))))
+           :use ((:instance a15 (i 2) (j1 1) (j2 (+ 3 (* -1 n) (* -1 (expt 2 (1- k))))))
                  (:instance expt-weak-monotone (n (+ 4 (* -1 n)
-                         (* -1 (expt 2 (+ -1 k)))))
+                         (* -1 (expt 2 (1- k)))))
            
-                       (m (+ 2 (* -1 (expt 2 (+ -1 k))))))))))
+                       (m (+ 2 (* -1 (expt 2 (1- k))))))))))
 #|
 ;BOZO kill move
 (defthm expo-shift-3-alt
@@ -1658,7 +1666,7 @@
                (equal (drnd x mode n k) (drnd x 'trunc n k))))
   :hints (("Goal" :use (:instance rnd-choice (x (+ X
                         (* (SGN X)
-                           (EXPT 2 (+ 2 (* -1 (EXPT 2 (+ -1 K)))))))))
+                           (EXPT 2 (+ 2 (* -1 (EXPT 2 (1- K)))))))))
            :in-theory (set-difference-theories
                        (enable drnd)
                        '(re evenp))))
@@ -1797,7 +1805,7 @@
                                       ;bias
                                      ; SMALLEST-POSITIVE-NORMAL
                                       rounding-mode-p
-                                      inf minf near sgn)
+                                      inf minf near near+ sgn)
                               '( ;BIAS
                                 ;sgn
                                 SMALLEST-POSITIVE-NORMAL
@@ -1864,7 +1872,7 @@
                               (enable drepp bias NEXT-DENORMAL-2)
                               '(fp+ fp+-expo))
            :use ((:instance fp+-expo (y x+)
-                            (n (+ -2 N (EXPO X) (EXPT 2 (+ -1 K)))))
+                            (n (+ -2 N (EXPO X) (EXPT 2 (1- K)))))
                  (:instance fp+1 
                             (y x+)
                             (n (+ -1 n (expo x) (bias k))))))))
@@ -2094,9 +2102,9 @@
                                       drnd-away-skips-no-denormals
                                       drnd-trunc-skips-no-denormals
                                       ))
-           :use ((:instance near1-b-eric (n (+ -2 N (EXPO X) (EXPT 2 (+ -1 K)))))
-                 (:instance away-lower-pos (n (+ -2 N (EXPO X) (EXPT 2 (+ -1 K)))))
-                 (:instance trunc-upper-pos (n (+ -2 N (EXPO X) (EXPT 2 (+ -1 K)))))
+           :use ((:instance near1-b-eric (n (+ -2 N (EXPO X) (EXPT 2 (1- K)))))
+                 (:instance away-lower-pos (n (+ -2 N (EXPO X) (EXPT 2 (1- K)))))
+                 (:instance trunc-upper-pos (n (+ -2 N (EXPO X) (EXPT 2 (1- K)))))
                  (:instance drnd-away-skips-no-denormals )
                  (:instance drnd-trunc-skips-no-denormals)))))
 
@@ -2120,9 +2128,9 @@
                                  away-exactp-c 
                                  trunc-exactp-c
                                  ))
-           :use ((:instance near1-a (n (+ -2 N (EXPO X) (EXPT 2 (+ -1 K)))))
-                 (:instance away-lower-pos (n (+ -2 N (EXPO X) (EXPT 2 (+ -1 K)))))
-                 (:instance trunc-upper-pos (n (+ -2 N (EXPO X) (EXPT 2 (+ -1 K)))))
+           :use ((:instance near1-a (n (+ -2 N (EXPO X) (EXPT 2 (1- K)))))
+                 (:instance away-lower-pos (n (+ -2 N (EXPO X) (EXPT 2 (1- K)))))
+                 (:instance trunc-upper-pos (n (+ -2 N (EXPO X) (EXPT 2 (1- K)))))
                  (:instance drnd-away-skips-no-denormals )
                  (:instance drnd-trunc-skips-no-denormals)))))
 
@@ -2224,7 +2232,7 @@
                x))
   :hints (("Goal" :in-theory (enable rnd)
            :use (:instance trunc-upper-bound
-                                  (n (+ -2 N (EXPO X) (EXPT 2 (+ -1 K))))))))
+                                  (n (+ -2 N (EXPO X) (EXPT 2 (1- K))))))))
 
 
 (defthm drnd-away-never-goes-down-for-pos-args
@@ -2239,7 +2247,7 @@
                x))
   :hints (("Goal" :in-theory (enable rnd)
            :use (:instance away-lower-bound
-                                  (n (+ -2 N (EXPO X) (EXPT 2 (+ -1 K))))))))
+                                  (n (+ -2 N (EXPO X) (EXPT 2 (1- K))))))))
 |#
 
 ;why?
