@@ -16,15 +16,24 @@
   (floor x 1))
 
 (defun bits (x i j)
-  (declare (xargs :guard (rationalp x)))
-  (if (or (not (integerp i))
-          (not (integerp j)))
-      0
-    (fl (/ (mod x (expt 2 (1+ i))) (expt 2 j)))))
+  (declare (xargs :guard (and (natp x)
+                              (natp i)
+                              (natp j))
+                  :verify-guards nil))
+  (mbe :logic (if (or (not (integerp i))
+                      (not (integerp j)))
+                  0
+                (fl (/ (mod x (expt 2 (1+ i))) (expt 2 j))))
+       :exec  (if (< i j)
+                  0
+                (logand (ash x (- j)) (1- (ash 1 (1+ (- i j))))))))
 
 (defund bitn (x n)
-    (declare (xargs :guard (rationalp x)))
-  (bits x n n))
+  (declare (xargs :guard (and (natp x)
+                              (natp n))
+                  :verify-guards nil))
+  (mbe :logic (bits x n n)
+       :exec  (if (evenp (ash x (- n))) 0 1)))
 
 (local (include-book "bits"))
 (local (include-book "bitn"))
@@ -46,10 +55,12 @@
 
 ;used to be called COMP1
 (defund lnot (x n)
-  (declare (xargs :guard (and (rationalp x)
-                              (integerp n))))
+  (declare (xargs :guard (and (natp x)
+                              (integerp n)
+                              (< 0 n))
+                  :verify-guards nil))
   (if (natp n)
-      (+ -1 (expt 2 n) (- (bits x (+ -1 n) 0)))
+      (+ -1 (expt 2 n) (- (bits x (1- n) 0)))
     0))
 
 ;note that this isn't a rewrite rule b/c we believe it will never need to be
@@ -192,13 +203,13 @@
 
 ;disable?
 (defthm lnot-ignores-bits
-  (equal (lnot (bits x (+ -1 n) 0) n)
+  (equal (lnot (bits x (1- n) 0) n)
          (lnot x n))
   :hints (("Goal" :in-theory (enable lnot))))
 
 (defthmd lnot-ignores-bits-2
   (implies (and (integerp i)
-                (<= (+ -1 n) i))
+                (<= (1- n) i))
            (equal (lnot (bits x i 0) n)
                   (lnot x n)))
   :hints (("Goal" :in-theory (enable lnot))))
@@ -218,9 +229,9 @@
                  (integerp k)
                  )
             (equal (fl (* (/ (expt 2 k)) (lnot x n)))
-                   (lnot (/ (bits x (+ -1 n) 0) (expt 2 k)) (- n k))))
+                   (lnot (/ (bits x (1- n) 0) (expt 2 k)) (- n k))))
    :hints (("Goal" :in-theory (disable lnot-fl-aux)
-            :use ((:instance lnot-fl-aux (x (bits x (+ -1 n) 0 ))))))
+            :use ((:instance lnot-fl-aux (x (bits x (1- n) 0 ))))))
    ))
 
 
@@ -243,7 +254,7 @@
                  (integerp n) 
                  (integerp k)
                  )
-            (equal (lnot (/ (bits x (+ -1 n) 0) (expt 2 k)) (- n k))
+            (equal (lnot (/ (bits x (1- n) 0) (expt 2 k)) (- n k))
                    (lnot (/ x (expt 2 k)) (- n k))))
    :hints (("Goal" :in-theory (e/d ( lnot) (
                                             LESS-THAN-MULTIPLY-THROUGH-BY-INVERTED-FACTOR-FROM-LEFT-HAND-SIDE)) ;BOZO
@@ -395,8 +406,8 @@
 
 ;BOZO move this!
 (defthm bits-ignores-mod-special
-  (equal (bits (mod x (expt 2 m)) (+ -1 m) 0)
-         (bits x (+ -1 m) 0)
+  (equal (bits (mod x (expt 2 m)) (1- m) 0)
+         (bits x (1- m) 0)
          )
   :hints (("goal" :in-theory (enable bits)))
   )
@@ -407,8 +418,8 @@
                 (case-split (integerp n))
                 ;(integerp m)
                 )
-           (equal (bits (mod x (expt 2 n)) (+ -1 m) 0)
-                  (bits x (+ -1 m) 0)
+           (equal (bits (mod x (expt 2 n)) (1- m) 0)
+                  (bits x (1- m) 0)
                   ))
   :hints (("goal" :in-theory (enable bits)))
   )
@@ -489,7 +500,7 @@
                 )
            (equal (bits (lnot x m) i j)
                   (lnot (bits x i j) (1+ (- i j)))))
-  :hints (("Goal" :use (:instance bits-lnot-aux (x (bits x (+ -1 m) 0)))
+  :hints (("Goal" :use (:instance bits-lnot-aux (x (bits x (1- m) 0)))
            :in-theory (e/d (bvecp) ()))))
 
 
@@ -561,7 +572,7 @@
                 (case-split (integerp n))
                 )
            (equal (lnot (* 2 x) n)
-                  (+ 1 (* 2 (lnot x (+ -1 n))))))
+                  (+ 1 (* 2 (lnot x (1- n))))))
   :hints (("Goal" :in-theory (enable lnot))))
 
 
