@@ -25,15 +25,24 @@
   (floor x 1))
 
 (defund bits (x i j)
-  (declare (xargs :guard (rationalp x)))
-  (if (or (not (integerp i))
-          (not (integerp j)))
-      0
-    (fl (/ (mod x (expt 2 (1+ i))) (expt 2 j)))))
+  (declare (xargs :guard (and (natp x)
+                              (natp i)
+                              (natp j))
+                  :verify-guards nil))
+  (mbe :logic (if (or (not (integerp i))
+                      (not (integerp j)))
+                  0
+                (fl (/ (mod x (expt 2 (1+ i))) (expt 2 j))))
+       :exec  (if (< i j)
+                  0
+                (logand (ash x (- j)) (1- (ash 1 (1+ (- i j))))))))
 
 (defund bitn (x n)
-    (declare (xargs :guard (rationalp x)))
-  (bits x n n))
+  (declare (xargs :guard (and (natp x)
+                              (natp n))
+                  :verify-guards nil))
+  (mbe :logic (bits x n n)
+       :exec  (if (evenp (ash x (- n))) 0 1)))
 
 (defun natp (x)
   (declare (xargs :guard t))
@@ -47,10 +56,12 @@
        (< x (expt 2 k))))
 
 (defund lnot (x n)
-  (declare (xargs :guard (and (rationalp x)
-                              (integerp n))))
+  (declare (xargs :guard (and (natp x)
+                              (integerp n)
+                              (< 0 n))
+                  :verify-guards nil))
   (if (natp n)
-      (+ -1 (expt 2 n) (- (bits x (+ -1 n) 0)))
+      (+ -1 (expt 2 n) (- (bits x (1- n) 0)))
     0))
 
 
