@@ -1,4 +1,4 @@
-; ACL2 Version 3.2 -- A Computational Logic for Applicative Common Lisp
+; ACL2 Version 3.3 -- A Computational Logic for Applicative Common Lisp
 ; Copyright (C) 2007  University of Texas at Austin
 
 ; This version of ACL2 is a descendent of ACL2 Version 1.9, Copyright
@@ -276,8 +276,9 @@ T     P,A  nil
         LD LD-ERROR-ACTION LD-ERROR-TRIPLES LD-KEYWORD-ALIASES
         LD-POST-EVAL-PRINT LD-PRE-EVAL-FILTER LD-PRE-EVAL-PRINT LD-PROMPT
         LD-QUERY-CONTROL-ALIST LD-REDEFINITION-ACTION LD-SKIP-PROOFSP
-        LD-VERBOSE LEGAL-CASE-CLAUSESP LEN LEN-UPDATE-NTH LENGTH LET* LIST
-        LIST* LIST*-MACRO LIST-ALL-PACKAGE-NAMES LIST-ALL-PACKAGE-NAMES-LST
+        LD-VERBOSE LEGAL-CASE-CLAUSESP LEN LEN-UPDATE-NTH LENGTH
+        LET* LIST LIST* LIST*-MACRO LIST-ALL-PACKAGE-NAMES
+        LIST-ALL-PACKAGE-NAMES-LST
         LIST-MACRO LISTP LOCAL LOGAND LOGANDC1 LOGANDC2 LOGBITP LOGCOUNT
         LOGEQV LOGIC LOGIOR LOGNAND LOGNOR LOGNOT LOGORC1 LOGORC2 LOGTEST
         LOGXOR LOWER-CASE-P LOWER-CASE-P-CHAR-DOWNCASE
@@ -340,7 +341,7 @@ T     P,A  nil
         SET-BODY SET-BOGUS-MUTUAL-RECURSION-OK SET-CASE-SPLIT-LIMITATIONS
         SET-CBD SET-COMPILE-FNS SET-DEFAULT-HINTS SET-DEFAULT-HINTS!
         SET-DIFFERENCE-EQ SET-DIFFERENCE-EQUAL SET-DIFFERENCE-THEORIES
-        SET-ENFORCE-REDUNDANCY SET-EQUALP-EQUAL SET-GUARD-CHECKING
+        SET-ENFORCE-REDUNDANCY SET-EQUALP-EQUAL SET-GAG-MODE SET-GUARD-CHECKING
         SET-IGNORE-OK SET-INHIBIT-OUTPUT-LST SET-INHIBIT-WARNINGS
         SET-INVISIBLE-FNS-TABLE SET-IRRELEVANT-FORMALS-OK SET-MEASURE-FUNCTION
         SET-NON-LINEARP SET-SAVED-OUTPUT SET-STATE-OK SET-TIMER
