@@ -1,4 +1,4 @@
-; ACL2 Version 3.2 -- A Computational Logic for Applicative Common Lisp
+; ACL2 Version 3.3 -- A Computational Logic for Applicative Common Lisp
 ; Copyright (C) 2007  University of Texas at Austin
 
 ; This version of ACL2 is a descendent of ACL2 Version 1.9, Copyright
@@ -90,6 +90,8 @@
   ; "meta-x start-proof-tree" starts proof-tree tracking in the current buffer
   ;      (where ACL2 is running).  See ACL2 documentation for PROOF-TREE for
   ;      more information.
+  ; Function start-proof-tree-noninteractive (see below) can be used to start
+  ;      proof-trees when emacs starts up; see below.
 ; Run ACL2 as inferior process
   ; "meta-x run-acl2" starts up acl2 as an inferior process in emacs.  You may
   ;      have better luck simply issuing your ACL2 command in an ordinary
@@ -101,6 +103,7 @@
   ;      subexpression.  See ACL2 documentation for PROOF-CHECKER.
   ; "control-t control-d" is like "control-t d" above, but for DIVE instead
   ;      (used with "pp" instead of "p")
+; Support for Dynamic Monitoring of Rewrites (dmr)
 ; Miscellaneous
   ; "meta-x acl2-info" brings up ACL2 documentation in pleasant emacs-info
   ;      format.
@@ -586,6 +589,24 @@ the next space does not pass fill-column."
   "Enable proof tree logging in a prooftree buffer."
   t)
 
+(autoload 'start-proof-tree-noninteractive
+  (concat (acl2-interface-dir) "top-start-shell-acl2")
+  "Enable proof tree logging in a prooftree buffer."
+  t)
+
+; You may find it useful to put some version of the following two forms in your
+; .emacs file.  It should start a new frame (perhaps after you click in the
+; initial emacs window) to the side of the first frame, with the "prooftree"
+; buffer displayed in the new frame.
+; (start-proof-tree-noninteractive "*shell*")
+; (cond ((and (eq window-system 'x)
+;             (fboundp 'x-display-pixel-width)
+;             (= (x-display-pixel-width) 2048) ; for a wide monitor
+;             )
+;        (delete-other-windows)
+;        (if (boundp 'emacs-startup-hook) ; false in xemacs
+;            (push 'new-prooftree-frame emacs-startup-hook))))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Run ACL2 as inferior process in emacs
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -610,20 +631,22 @@ the next space does not pass fill-column."
 ; This is for use with the PP command.
 (define-key ctl-t-keymap "\C-d" 'dive-manual)
 
-; The following may be useful to put in one's .emacs file if there are problems
-; getting whole words viewed as whole words.
-
-;(add-hook 'comint-mode-hook
-;	  '(lambda ()
-;	     (modify-syntax-entry ?- "w")
-;	     (modify-syntax-entry ?: "w")
-;	     (modify-syntax-entry ?_ "w")
-;	     (modify-syntax-entry ?+ "w")
-;	     (modify-syntax-entry ?* "w")
-;	     ))
-
 ; The rest of the functions in this section support \C-t d and \C-t \C-d. 
 
+(defvar *acl2-pc-dive-syntax-table* nil)
+
+(defun maybe-set-acl2-pc-dive-syntax-table ()
+  (cond ((null *acl2-pc-dive-syntax-table*)
+	 (setq *acl2-pc-dive-syntax-table*
+	       (copy-syntax-table (syntax-table)))
+	 (modify-syntax-entry ?- "w" *acl2-pc-dive-syntax-table*)
+	 (modify-syntax-entry ?: "w" *acl2-pc-dive-syntax-table*)
+	 (modify-syntax-entry ?_ "w" *acl2-pc-dive-syntax-table*)
+	 (modify-syntax-entry ?+ "w" *acl2-pc-dive-syntax-table*)
+	 (modify-syntax-entry ?* "w" *acl2-pc-dive-syntax-table*)
+	 (modify-syntax-entry ?. "w" *acl2-pc-dive-syntax-table*)
+	 *acl2-pc-dive-syntax-table*)))
+
 (defun dive-manual ()
   "Returns the 0-based address of the current s-expression inside
 the expression beginning at the margin, assuming that the point
@@ -636,7 +659,7 @@ at the top."
     (end-of-buffer)
     (if (null addr)
 	(error "Null address.")
-	(insert (prin1-to-string (cons 'dive addr))))))
+      (insert (prin1-to-string (cons 'dive addr))))))
 
 (defun dv-manual ()
   "Returns the 0-based address of the current s-expression inside
@@ -649,7 +672,7 @@ command for the proof-checker. Causes an error if one is already at the top."
     (end-of-buffer)
     (if (null addr)
 	(error "Null address.")
-	(insert (prin1-to-string (cons 'dv addr))))))
+      (insert (prin1-to-string (cons 'dv addr))))))
 
 (defun beginning-of-current-defun ()
   "Causes an error if one is already at the beginning of defun, in
@@ -664,16 +687,18 @@ the sense of c-m-a"
 (defun find-address ()
   "Returns the 0-based address of the current s-expression inside
 the expression beginning at the margin.  Leaves one at the original point."
-;  (interactive)
-  (let (quit-point old-point result)
-    (setq old-point (point))
-    (beginning-of-current-defun)
-    (setq quit-point (point))
-    (goto-char old-point)
-    (while (not (equal (point) quit-point))
-      (setq result (cons (move-up-one-level) result)))
-    (goto-char old-point)
-    result))
+  (maybe-set-acl2-pc-dive-syntax-table)
+  (with-syntax-table
+      *acl2-pc-dive-syntax-table*
+    (let (quit-point old-point result)
+      (setq old-point (point))
+      (beginning-of-current-defun)
+      (setq quit-point (point))
+      (goto-char old-point)
+      (while (not (equal (point) quit-point))
+	(setq result (cons (move-up-one-level) result)))
+      (goto-char old-point)
+      result)))
 
 (defun move-up-one-level ()
   "Like backward-up-list, except that it returns the position
@@ -693,6 +718,12 @@ of the current s-expression in the enclosing list"
     (goto-char final-point)
     n))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;;; Support for Dynamic Monitoring of Rewrites (dmr)
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(load (concat (acl2-sources-dir) "emacs/monitor.el"))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Miscellaneous
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
