@@ -1,4 +1,4 @@
-; ACL2 Version 3.2 -- A Computational Logic for Applicative Common Lisp
+; ACL2 Version 3.3 -- A Computational Logic for Applicative Common Lisp
 ; Copyright (C) 2007  University of Texas at Austin
 
 ; This version of ACL2 is a descendent of ACL2 Version 1.9, Copyright
@@ -182,7 +182,8 @@
                                       pt nonlinearp
                                       type-alist ens force-flg wrld)))))))
 
-(defun add-polys (lst pot-lst pt nonlinearp type-alist ens force-flg wrld)
+(defun add-polynomial-inequalities (lst pot-lst pt nonlinearp type-alist ens
+                                        force-flg wrld)
 
 ; Wrapper for the old add-polys (now add-polys0) so that we can
 ; eliminate the use of cancel-poly-against-type-set from within add-poly.
@@ -207,6 +208,27 @@
                                        pt nonlinearp
                                        type-alist ens force-flg wrld))))))
 
+#-acl2-loop-only
+(defparameter *add-polys-counter*
+
+; This is used by dmr-string to show the cumulative number of calls of
+; add-polys, as requested by Robert Krug.
+
+  0)
+
+(defun add-polys (lst pot-lst pt nonlinearp type-alist ens force-flg wrld)
+  #-acl2-loop-only
+  (when (f-get-global 'dmrp *the-live-state*)
+    (return-from
+     add-polys
+     (progn
+       (incf *add-polys-counter*)
+       (pstk
+        (add-polynomial-inequalities lst pot-lst pt nonlinearp type-alist ens
+                                     force-flg wrld)))))
+  (add-polynomial-inequalities lst pot-lst pt nonlinearp type-alist ens
+                               force-flg wrld))
+
 
 ;=================================================================
 
