@@ -188,18 +188,28 @@
 	     (push (trace-entry (car x) (cddr x)) new-lst)
 	     (push `(ccl:unadvise ,(car x)) new-lst))))))
 	
+(defun acl2-traced-fns ()
+  (let (val)
+    (dolist (capsule ccl::*advise-alist*)
+      (pushnew (ccl::encapsulation-spec capsule)
+               val))
+    val))
+
 (let ((temp ccl::*warn-if-redefine-kernel*))
   (setf ccl::*warn-if-redefine-kernel* nil)
   (defmacro trace (&rest fns)
-    (cons 'progn
-          (trace-process (trace-pre-process fns))))
+    (if fns
+        (cons 'progn
+              (trace-process (trace-pre-process fns)))
+      '(acl2-traced-fns)))
   (setf ccl::*warn-if-redefine-kernel* temp))
 
 (let ((temp ccl::*warn-if-redefine-kernel*))
   (setf ccl::*warn-if-redefine-kernel* nil)
   (defmacro untrace (&rest fns)
     (if (null fns)
-        '(ccl:unadvise t)
+        '(prog1 (acl2-traced-fns)
+           (ccl:unadvise t))
       (cons 'progn
             (let ((ans nil))
               (dolist (fn fns ans)
