@@ -1,4 +1,4 @@
-; ACL2 Version 3.2 -- A Computational Logic for Applicative Common Lisp
+; ACL2 Version 3.3 -- A Computational Logic for Applicative Common Lisp
 ; Copyright (C) 2007  University of Texas at Austin
 
 ; This version of ACL2 is a descendent of ACL2 Version 1.9, Copyright
@@ -1265,7 +1265,10 @@
       (if raw-term-supplied-p
           (state-global-let*
            ((in-verify-flg t)
-            (print-base 10))
+            (print-base 10)
+            (inhibit-output-lst
+             (remove1-eq 'proof-checker
+                         (f-get-global 'inhibit-output-lst state))))
            (pc-top raw-term event-name rule-classes
                    (append instructions *standard-oi*)
                    (list 'exit)
@@ -1287,7 +1290,10 @@
                     bad-fn)
               (state-global-let*
                ((in-verify-flg t)
-                (print-base 10))
+                (print-base 10)
+                (inhibit-output-lst
+                 (remove1-eq 'proof-checker
+                             (f-get-global 'inhibit-output-lst state))))
                (pc-main-loop (append instructions *standard-oi*)
                              (list 'exit)
                              t t state))))))
@@ -1323,7 +1329,7 @@
           (declare (ignore erp val))
           state))
 
-(defun print-defthm (ev state)
+(defun print-pc-defthm (ev state)
   (let ((ldd (make-ldd 'event nil #\Space 0 t
                        ev)))
     (io? proof-checker nil state
@@ -1334,7 +1340,7 @@
                             (access-ldd-fullp ldd)
                             (access-ldd-form ldd))))))))
 
-(defmacro print-goal (&optional goal)
+(defmacro print-pc-goal (&optional goal)
   `(let ((goal ,(or goal '(car (access pc-state (car (state-stack)) :goals)))))
      (io? proof-checker nil state
           (goal)
